crabnet.data.materials\_data.elasticity package
===============================================

Module contents
---------------

.. automodule:: crabnet.data.materials_data.elasticity
   :members:
   :undoc-members:
   :show-inheritance:
